# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We have db4 up to Fedora 13 and RHEL 6, then db5 (in the libdb package)
%if %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -gt 13 ")" -o "(" "%{__distinit}" == "rhel" -a %{__distvers} -gt 6 ")" ] && echo 1 || echo 0)
%global db_pkg libdb
%else
%global db_pkg db4
%endif

# We need to know the exact DB version we're built against
%global db_ver %(sed '/DB_VERSION_STRING/!d;s/.*Berkeley DB[[:space:]]*\\([^:]*\\):.*/\\1/' /usr/include/db.h 2>/dev/null || echo 4.0.0)

Summary:	Interface to Berkeley DB
Name:		perl-BerkeleyDB
Version:	0.55
Release:	6.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/BerkeleyDB/
Source0:	http://search.cpan.org/CPAN/authors/id/P/PM/PMQS/BerkeleyDB-%{version}.tar.gz
Patch0:		BerkeleyDB-0.34-config.in.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	%{db_pkg}-devel
BuildRequires:	perl
%if 0%{?fedora} > 6 || 0%{?rhel} > 5
BuildRequires:	perl-devel
%endif
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(strict)
BuildRequires:	perl(UNIVERSAL)
BuildRequires:	perl(vars)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(charnames)
BuildRequires:	perl(constant)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Encode)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(lib)
BuildRequires:	perl(MLDBM)
BuildRequires:	perl(overload)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(threads::shared)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
# Hard-code Berkeley DB requirement to avoid problems like #592209
Requires:	%{db_pkg} = %{db_ver}
Requires:	perl(XSLoader)

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
BerkeleyDB is a module that allows Perl programs to make use of the
facilities provided by Berkeley DB version 2 or greater (note: if
you want to use version 1 of Berkeley DB with Perl you need the DB_File
module).

Berkeley DB is a C library that provides a consistent interface to a
number of database formats. BerkeleyDB provides an interface to all
four of the database types (hash, btree, queue and recno) currently
supported by Berkeley DB.

%prep
%setup -q -n BerkeleyDB-%{version}
%patch0 -p1 -b .config

perl -pi -e 's,/local/,/, if ($. == 1)' dbinfo
chmod -c -x Changes README

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} %{buildroot}
install -D -m 755 dbinfo %{buildroot}%{_bindir}/dbinfo

# Remove files we don't want packaged
rm %{buildroot}%{perl_vendorarch}/{mkconsts,scan}.pl

%check
make test

%clean
rm -rf %{buildroot}

%files
%doc README Changes Todo
%{_bindir}/dbinfo
%{perl_vendorarch}/BerkeleyDB/
%{perl_vendorarch}/BerkeleyDB.pm
%doc %{perl_vendorarch}/BerkeleyDB.pod
%{perl_vendorarch}/auto/BerkeleyDB/
%{_mandir}/man3/BerkeleyDB.3*

%changelog
* Fri Aug  5 2016 Paul Howarth <paul@city-fan.org> - 0.55-6
- Specify all build requirements
- Simplify find commands using -empty and -delete

* Thu Jun 18 2015 Paul Howarth <paul@city-fan.org> - 0.55-3
- Perl 5.22 rebuild

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 0.55-1
- Update to 0.55
  - Error opening ErrFile with PerlIO_findFILE (CPAN RT#101883)
  - Minor updates for BDB 6.1
- Classify buildreqs by usage

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> 0.54-4
- Drop %%defattr, redundant since rpm 4.4

* Sun Nov 10 2013 Paul Howarth <paul@city-fan.org> 0.54-1
- Update to 0.54
  - Fix memory leak in CDS locking routines (CPAN RT#90134)

* Wed Oct  9 2013 Paul Howarth <paul@city-fan.org> 0.53-2
- Rebuild for libdb 5.3.28 in Rawhide

* Fri Aug 16 2013 Paul Howarth <paul@city-fan.org> 0.53-1
- Update to 0.53
  - BerkeleyDB 0.52 failed to build on 5.18.1RC3 (CPAN RT#87771)
  - Typo fixes (CPAN RT#86705)

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> 0.52-2
- Perl 5.18 rebuild

* Tue Jun 11 2013 Paul Howarth <paul@city-fan.org> 0.52-1
- Update to 0.52
  - Updates for BDB 6.0 - added Blob support
    - Added BerkeleyDB::DbStream class to interface to Blobs
    - Added BlobThreshold and BlobDir options to BerkeleyDB::Env constructor
    - Added BlobThreshold and BlobDir options to Hash, Btree and Heap
      constructors
    - Added get_blob_threshold method to BerkeleyDB::Env
    - Added get_blob_dir method to BerkeleyDB::Env
    - Added get_blob_threshold method to Hash, Btree and Heap
    - Added get_blob_dir method to Hash, Btree and Heap
  - Added method $cursor->set_partial
  - Added method $cursor->partial_clear
  - Fixed $env->lock_detect dies due to incorrect version check (CPAN RT#84179)
  - Fixed memory leak in db_verify() method with libdb < 4.2 (CPAN RT##84409)
  - Fixed a few croaks

* Thu Jul  5 2012 Paul Howarth <paul@city-fan.org> 0.51-4
- Perl 5.16 rebuild

* Thu Jul  5 2012 Paul Howarth <paul@city-fan.org> 0.51-3
- Rebuild for libdb 5.3.21 in Rawhide
- Rename config patch:
  perl-BerkeleyDB-0.34-config.in.patch => BerkeleyDB-0.34-config.in.patch

* Thu Apr  5 2012 Paul Howarth <paul@city-fan.org> 0.51-2
- Rebuild for libdb 5.3.15 in Rawhide

* Tue Mar 20 2012 Paul Howarth <paul@city-fan.org> 0.51-1
- Update to 0.51
  - Rework FETCHSIZE (CPAN RT#75691)
- BR: perl(AutoLoader), perl(Carp), perl(Exporter) and perl(IO::File)
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Don't need rpath-removal kludge
  - Use %%{_fixperms} macro rather than our own chmod incantation
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Dec 10 2011 Paul Howarth <paul@city-fan.org> 0.50-1
- Update to 0.50
  - Updates for BDB 5.3
- Anticipate RHEL 7 having libdb

* Wed Sep 21 2011 Paul Howarth <paul@city-fan.org> 0.49-2
- BR: perl(Cwd) as Cwd is no longer in core

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> 0.49-1
- Update to 0.49
  - Documentation updated courtesy of Mike Caron
  - Croak if attempt to freeze BerkeleyDB object (CPAN RT#69985)

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> 0.48-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sun Jun 19 2011 Paul Howarth <paul@city-fan.org> 0.48-1
- Update to 0.48
  - Added support for db_exists and lock_detect
  - Fixed bug with c_pget when the DB_GET_BOTH flag is used
  - Fixed bug with db_pget when the DB_GET_BOTH flag is used
  - Changes to build with BDB 5.2
  - Add support for new Heap database format
  - Fixed test harness issue with Heap.t (CPAN RT#68818)
- Don't package build tools mkconsts.pl and scan.pl
- Nobody else likes macros for commands

* Fri Feb  4 2011 Paul Howarth <paul@city-fan.org> 0.43-4
- Rebuild for libdb 5.1.25 in Rawhide

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> 0.43-3
- Rebuild for gcc bug (#634757)

* Sun Sep 12 2010 Paul Howarth <paul@city-fan.org> 0.43-2
- Rebuild for libdb 5.1.19 in Rawhide

* Mon Aug  2 2010 Paul Howarth <paul@city-fan.org> 0.43-1
- Update to 0.43
  - Changes to build with BDB 5.1
  - Dropped support for Server option when creating an environment
  - Documentation updates (CPAN RT#59202)
  - Fixed compilation error with MS Visual Studio 2005 (CPAN RT#59924)

* Wed Jul  7 2010 Paul Howarth <paul@city-fan.org> 0.42-6
- Rebuild for Berkeley DB 5.0.26 in Rawhide

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> 0.42-5
- Rebuild for Berkeley DB 5.0.21 and perl 5.12.1 in Rawhide

* Wed May 26 2010 Paul Howarth <paul@city-fan.org> 0.42-4
- Rebuild for Berkeley DB 4.8.30 in F-13 (#592209)
- Use same macro for Berkeley DB version extraction as in Fedora

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> 0.42-3
- Rebuild for Berkeley DB 4.8.30 in Rawhide (#592209)
- Hard-code Berkeley DB requirement to avoid problems like #592209

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> 0.42-2
- Fix dist tag to work with RHEL6 Beta

* Sun Mar 14 2010 Paul Howarth <paul@city-fan.org> 0.42-1
- Update to 0.42
  - added $db->Env method to retrieve environment object from a database object
  - get the tied interface to use truncate in the CLEAR method if available

* Mon Jan 11 2010 Paul Howarth <paul@city-fan.org> 0.41-1
- Update to 0.41
  - silence "UNIVERSAL->import is deprecated" in perl 5.11 - CPAN RT#53518

* Thu Jan  7 2010 Paul Howarth <paul@city-fan.org> 0.40-1
- Update to 0.40 (added support for set_tx_max, log_set_config,
  set_lk_max_lockers, set_lk_max_locks, set_lk_max_objects via the Env
  constructor - CPAN RT#50456)
- Use %%{?perl_default_filter} for provides filter
- Dist tag for Rawhide no longer needs special-casing

* Wed Sep  2 2009 Paul Howarth <paul@city-fan.org> 0.39-2
- Improve the provides filter to not filter out stuff we still want

* Mon Jun  8 2009 Paul Howarth <paul@city-fan.org> 0.39-1
- Update to 0.39
- * added support for BDB 4.8 (associate_foreign, set_bt_compress)
- * added interface to ENV->stat_print, ENV->txn_stat_print
- * fixed issue db_stat when it returned a null pointer (CPAN RT#46312)
- * fixed issue with DNM Filters and UTF8 support

* Sun Mar  1 2009 Paul Howarth <paul@city-fan.org> 0.38-2
- Filter out unwanted provides for perl shared objects
- Update to SLES-compatible dist tag macros

* Mon Feb 23 2009 Paul Howarth <paul@city-fan.org> 0.38-1
- Update to 0.38 (patches needed for 0.37 upstreamed)

* Thu Feb 19 2009 Paul Howarth <paul@city-fan.org> 0.37-1
- Update to 0.37 (include CDS section in the pod, various documentation patches
  from CPAN RT#42243)
- Fix pod so that it doesn't fail the pod test
- Fix t/util.pm to work with releases older than Fedora 9

* Wed Oct  1 2008 Paul Howarth <paul@city-fan.org> 0.36-1
- Update to 0.36

* Wed Sep 17 2008 Paul Howarth <paul@city-fan.org> 0.35-1
- Update to 0.35
- Add buildreq perl(ExtUtils::MakeMaker)

* Fri Mar 28 2008 Paul Howarth <paul@city-fan.org> 0.34-1
- Update to 0.34
- Update config patch

* Fri Jan 18 2008 Paul Howarth <paul@city-fan.org> 0.33-1
- Update to 0.33
- Update config patch
- Clarify ilcense as GPL version 1 or later, or Artistic (i.e. same as perl)

* Thu Jul 12 2007 Paul Howarth <paul@city-fan.org> 0.32-1
- Update to 0.32
- Fix dist tag for Fedora 7 onwards

* Wed Oct 18 2006 Paul Howarth <paul@city-fan.org> 0.31-2
- Rebuild (forgot to sign packages)

* Tue Oct 17 2006 Paul Howarth <paul@city-fan.org> 0.31-1
- Update to 0.31

* Thu Sep 14 2006 Paul Howarth <paul@city-fan.org> 0.30-1
- Update to 0.30
- Fix dist tag for development builds

* Mon Jul  3 2006 Paul Howarth <paul@city-fan.org> 0.29-1
- Update to 0.29

* Mon Jun 12 2006 Paul Howarth <paul@city-fan.org> 0.28-1
- Update to 0.28
- Build on CentOS/Whitebox treated as build on RHEL
- Define %%{__id_u} in a more portable way
- Drop explicit db4 dependency; soname auto-dep will suffice

* Tue Nov  1 2005 Paul Howarth <paul@city-fan.org> 0.27-1
- Update to 0.27
- Simplify distribution-detection, not using rpmdb query
- Simplify compiler optimization setting
- Remove buildroot unconditionally in %%install and %%clean
- Don't use macros in build-time command pathnames, hardcode them instead
- Tag BerkeleyDB.pod as %%doc
- Use search.cpan.org URLs

* Fri Sep  2 2005 Paul Howarth <paul@city-fan.org> 0.26-5
- Add note about the package being included in Fedora Extras
- Add BR: perl(Test::Pod)

* Tue Aug  2 2005 Paul Howarth <paul@city-fan.org> 0.26-4
- Add dbinfo utility
- Add Todo
- Fix permissions of docs
- Fix LD_RUN_PATH in Makefile

* Tue Jun 14 2005 Paul Howarth <paul@city-fan.org> 0.26-3
- BuildRequire perl-MLDBM for better test coverage

* Sat Jun  4 2005 Paul Howarth <paul@city-fan.org> 0.26-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Fri Oct 22 2004 Paul Howarth <paul@city-fan.org> 0.26-1
- Update to 0.26
- Tidy up spec file

* Mon May 03 2004 Paul Howarth <paul@city-fan.org> 0.25-1
- Initial build
